@@ -1,5 +1,7 @@
 #!/usr/bin/env python
 from __future__ import print_function
+
+from sgtlibc.utils.compat import deprecated
 from .. import logger
 import os
 import re
@@ -22,8 +24,10 @@ class LibcSearcher(object):
         self.libc_database_path = os.path.join(
             os.path.realpath(os.path.dirname(__file__)), os.pardir, f"libc-database{os.sep}db{os.sep}")
         self.libc_database_path = os.path.realpath(self.libc_database_path)
-        self.db = ""
+        self.__db = []
         self.current_focus_db = 0
+        self.current_filter = None
+        self.is_first_filter = True
         self.init_db()
 
     def init_db(self):
@@ -57,7 +61,7 @@ class LibcSearcher(object):
         self.conditions[func] = address
         self.condition_reg[func] = re_compile
 
-    def decided(self, max_show_count: int = 5) -> Tuple:
+    def decided(self, max_show_count: int = 5, filter: Callable = None) -> Tuple:
         '''
         matching libc-database with condition(s)
         return is_found,db_description,db_count
@@ -70,7 +74,8 @@ class LibcSearcher(object):
         self.list_conditions()
         self.search_db()
         return self.list_db(
-            max_show_count=max_show_count
+            max_show_count=max_show_count,
+            filter=filter
         )
 
     def list_conditions(self):
@@ -97,19 +102,44 @@ class LibcSearcher(object):
                         break
                 if fitted_libc:
                     result.append(symbol_file)
-        self.db = result
+        self.__db = result
 
-    def list_db(self, max_show_count: int = 5):
+    @property
+    @deprecated("Use all_db([filter]) to get databases")
+    def db(self):
+        import openpyxl
+        return self.all_db()
+
+    def all_db(self, filter: Callable = None):
+        db_list = self.__db
+        if not db_list:
+            return []
+        if not filter:
+            def filter(x): return True
+        result = [x for x in db_list if filter(x)]
+        filter_count = len(db_list) - len(result)
+        if filter_count > 0:
+            notice = f'{filter_count} db(s) is filtered by user-setting.'
+            if self.is_first_filter:
+                self.is_first_filter = False
+                hidden = list(set(db_list).difference(set(result)))
+                hidden = '\n'.join(list2sheet(hidden))
+                notice = f'{notice}\n{hidden}'
+            logger.warning(notice)
+        return result
+
+    def list_db(self, max_show_count: int = 5, filter: Callable = None):
         '''
         return is_found,db_description,db_count
         '''
-        result = self.db
+        result = self.all_db(filter=filter)
         count = len(result)
         if count == 0:
-            logger.error("No matched libc, please add more libc or try others")
+            logger.error(
+                "No matched libc, please add more libc or try others elf.got.")
             return False, None, 0
         result = '\n'.join(list2sheet(
-            lines=self.db,
+            lines=result,
             line_renderer=lambda x: self.pmore(x),
             max_show_count=max_show_count
         ))
@@ -126,12 +156,18 @@ class LibcSearcher(object):
             info = 'noalias'
         return f'{info} ({result})'
 
-    def dump(self, func: List = None, db_index: int = -1, max_show_count: int = 5):
+    def dump(self, func: List = None, db_index: int = -1, max_show_count: int = 5, filter: Callable = None):
         '''
         dump libc-addr from search-result
         func: List[str] the function address to get
         db_index: from 0 to n , default use `current_focus_db`
+        filter: Callable[libc_name:str]->bool , filter result with this predict
         '''
+        if not filter:
+            filter = self.current_filter
+        else:
+            self.current_filter = filter
+            self.is_first_filter = True
         if db_index < 0:
             db_index = self.current_focus_db
         elif self.current_focus_db != db_index:
@@ -141,20 +177,25 @@ class LibcSearcher(object):
         if not isinstance(db_index, int):
             db_index = int(db_index)
         # check if no result been calculated
-        if not self.db:
+        db_list = self.all_db(filter=filter)
+        if not self.__db:
             self.__db_result = self.decided(
-                max_show_count=max_show_count
+                max_show_count=max_show_count,
+                filter=filter
             )
             if not self.__db_result[0]:
                 return False
-        if len(self.db) < db_index + 1:
+            db_list = self.all_db(filter=filter)
+
+        if len(db_list) < db_index + 1:
             logger.error(
                 f'db[{db_index}] not exist.\n')
             self.list_db(
-                max_show_count=max_show_count
+                max_show_count=max_show_count,
+                filter=filter
             )
             return
-        db_name = self.db[db_index]
+        db_name = db_list[db_index]
         logger.debug(f'dumping db[{db_index}]:{self.pmore(db_name)}')
         db = f'{self.libc_database_path}{os.sep}{db_name}'
         with open(db, 'rb') as fd:
